import ExclamationMarkIcon from 'assets/icons/ico/exclamationMark.svg'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import React, { useEffect, useMemo, useState } from 'react'
import ConsumptionService from 'services/consumption.service'
import { useAppSelector } from 'store/hooks'
import TemperatureComparisonModal from './TemperatureComparisonModal/TemperatureComparisonModal'
import './temperatureComparison.scss'

const TemperatureComparison = () => {
  const { t } = useI18n()
  const client = useClient()
  const { period, analysisMonth } = useAppSelector(
    state => state.ecolyo.analysis
  )

  const [temperatureDifference, setTemperatureDifference] = useState<string>()
  const [positive, setPositive] = useState<boolean>(true)
  const [openTemperatureComparisonModal, setOpenTemperatureComparisonModal] =
    useState<boolean>(false)
  const consumptionService = useMemo(
    () => new ConsumptionService(client),
    [client]
  )
  const comparisonDates = useMemo(() => {
    const endMonth = analysisMonth.minus({ month: 1 }).startOf('month')
    return {
      startMonth: endMonth
        .minus({ month: period === 'month' ? 1 : 12 })
        .startOf('month'),
      endMonth: endMonth,
    }
  }, [analysisMonth, period])

  useEffect(() => {
    async function handleTemperatureComparison() {
      const startMonthTemperature =
        await consumptionService.fetchAvgTemperature(
          comparisonDates.startMonth.year,
          comparisonDates.startMonth.month
        )

      const endMonthTemperature = await consumptionService.fetchAvgTemperature(
        comparisonDates.endMonth.year,
        comparisonDates.endMonth.month
      )

      if (startMonthTemperature !== null && endMonthTemperature !== null) {
        const temperatureDifference =
          endMonthTemperature - startMonthTemperature
        setTemperatureDifference(temperatureDifference.toFixed(1))
        setPositive(temperatureDifference >= 0)
      }
    }
    handleTemperatureComparison()
  }, [
    consumptionService,
    comparisonDates.endMonth.month,
    comparisonDates.endMonth.year,
    comparisonDates.startMonth.month,
    comparisonDates.startMonth.year,
  ])

  return (
    <>
      {temperatureDifference && (
        <div className={`temperatureComparison ${positive ? 'hot' : 'cold'}`}>
          <div className="tc-content">
            <div>
              <span className="text-28-bold">
                {positive ? '+' : ''}
                {temperatureDifference}&nbsp;
              </span>
              <span className="text-18">
                {t('analysis.temperature_comparison.unit')}
              </span>
            </div>
            <div>
              <span className="tc-text text-12">
                {t('analysis.temperature_comparison.comparison')}
              </span>
              <span className="tc-period text-12-bold">
                &nbsp;
                {comparisonDates.startMonth.toLocaleString({
                  month: 'long',
                  year: 'numeric',
                })}
              </span>
            </div>
          </div>

          <StyledIconButton
            icon={ExclamationMarkIcon}
            sized={16}
            onClick={() => setOpenTemperatureComparisonModal(true)}
            aria-label={t('analysis.temperature_comparison.info_button')}
            className="info-icon"
          />

          <TemperatureComparisonModal
            open={openTemperatureComparisonModal}
            handleCloseClick={() => setOpenTemperatureComparisonModal(false)}
          />
        </div>
      )}
    </>
  )
}

export default TemperatureComparison
