import { render } from '@testing-library/react'
import { DateTime } from 'luxon'
import React from 'react'
import { Provider } from 'react-redux'
import { dataLoadArray } from 'tests/__mocks__/chartData.mock'
import { createMockEcolyoStore, mockGlobalState } from 'tests/__mocks__/store'
import ElecHalfHourChart from './ElecHalfHourChart'

jest.mock('services/dateChart.service', () => {
  return jest.fn(() => ({
    compareStepDate: jest.fn(),
  }))
})

describe('ElecHalfHourChart component', () => {
  const store = createMockEcolyoStore({
    chart: {
      selectedDate: DateTime.fromISO('2021-07-01T00:00:00.000Z', {
        zone: 'utc',
      }),
    },
    global: mockGlobalState,
  })
  it('should be rendered correctly', () => {
    const { container } = render(
      <Provider store={store}>
        <ElecHalfHourChart dataLoad={dataLoadArray} isWeekend={true} />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })
  it('should render week data', () => {
    const { container } = render(
      <Provider store={store}>
        <ElecHalfHourChart dataLoad={dataLoadArray} isWeekend={false} />
      </Provider>
    )
    expect(container.getElementsByClassName('week').length).toBeTruthy()
  })
})
