import { ScaleBand, ScaleLinear } from 'd3-scale'
import { detect } from 'detect-browser'
import { DateTime } from 'luxon'
import { Dataload } from 'models'
import React, { useState } from 'react'

interface BarProps {
  index: number
  dataload: Dataload
  xScale: ScaleBand<string>
  yScale: ScaleLinear<number, number>
  height: number
  average: number
}

const UpcomingBar = ({
  index,
  dataload,
  xScale,
  yScale,
  height,
  average,
}: BarProps) => {
  const [animationEnded, setAnimationEnded] = useState(false)
  const browser = detect()
  const onAnimationEnd = () => {
    setAnimationEnded(true)
  }

  let animationClass = ''
  if (!animationEnded) {
    animationClass = browser?.name !== 'edge' ? 'bounce-1' : 'bounce-3'
    animationClass += ` delay--${index % 13}`
  }
  const barClass = `bar-UPCOMING ${animationClass}`

  const topRoundedRectDashedLine = (
    x: number,
    y: number,
    width: number,
    height: number
  ): string => {
    const radius = height > 4 ? 4 : height / 4
    return (
      'M' +
      x +
      ',' +
      (y + radius + (height - radius)) +
      'v-' +
      (height - radius) +
      ' a' +
      radius +
      ',' +
      radius +
      ' 0 0 1 ' +
      radius +
      ',' +
      -radius +
      'h' +
      (width - 2 * radius) +
      'a' +
      radius +
      ',' +
      radius +
      ' 0 0 1 ' +
      radius +
      ',' +
      radius +
      'v' +
      (height - radius)
    )
  }

  return (
    <g>
      {height > 0 && (
        <g
          transform={`translate(${xScale(
            dataload.date.toLocaleString(DateTime.DATETIME_SHORT)
          )}, -40)`}
        >
          <rect
            x="0"
            y="0"
            width={xScale.bandwidth()}
            height={height + 40}
            className="background-false"
            fill="#E0E0E0"
          />
        </g>
      )}
      {height > 0 && average >= 0 && (
        <g
          transform={`translate(${xScale(
            dataload.date.toLocaleString(DateTime.DATETIME_SHORT)
          )}, ${yScale(average)})`}
        >
          <path
            d={topRoundedRectDashedLine(
              0,
              0,
              xScale.bandwidth(),
              height - yScale(average)
            )}
            fill="url(#gradient)"
            strokeDasharray="5"
            stroke="#61f0f2"
            onAnimationEnd={onAnimationEnd}
            className={barClass}
          />
        </g>
      )}
    </g>
  )
}

export default UpcomingBar
