import { act, render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import { FluidType } from 'enums'
import React from 'react'
import { Provider } from 'react-redux'
import * as storeHooks from 'store/hooks'
import { fluidStatusConnectedData } from 'tests/__mocks__/fluidStatusData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import ExpiredConsentModal from './ExpiredConsentModal'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))
const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')
const mockHandleCloseClick = jest.fn()

describe('ExpiredConsentModal component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })
  it('should be rendered correctly', () => {
    const { baseElement } = render(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={jest.fn()}
          fluidType={FluidType.ELECTRICITY}
          toggleModal={jest.fn()}
        />
      </Provider>
    )
    expect(baseElement).toMatchSnapshot()
  })
  it('should launch the update consent process for GRDF', async () => {
    render(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={jest.fn()}
          fluidType={FluidType.GAS}
          toggleModal={jest.fn()}
        />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('consent_outdated.go'))
    })
    expect(mockAppDispatch).toHaveBeenCalledTimes(1)
    expect(mockedNavigate).toHaveBeenCalledTimes(1)
  })
  it('should launch the update consent process for Enedis', async () => {
    const store = createMockEcolyoStore({
      global: { fluidStatus: fluidStatusConnectedData },
    })
    render(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={jest.fn()}
          fluidType={FluidType.ELECTRICITY}
          toggleModal={jest.fn()}
        />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('consent_outdated.yes'))
    })
    expect(mockAppDispatch).toHaveBeenCalledTimes(1)
    expect(mockedNavigate).toHaveBeenCalledTimes(1)
  })
  it('should click on close modal', async () => {
    render(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={mockHandleCloseClick}
          fluidType={FluidType.ELECTRICITY}
          toggleModal={jest.fn()}
        />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('consent_outdated.no'))
    })
    expect(mockHandleCloseClick).toHaveBeenCalled()
  })
})
