import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import IconButton from '@material-ui/core/IconButton'
import CloseIcon from 'assets/icons/ico/close.svg'
import DefaultIcon from 'assets/icons/visu/ecogesture/bullhorn.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { DateTime } from 'luxon'
import { CustomPopup } from 'models'
import React, { useEffect, useState } from 'react'
import { importIconById } from 'utils/utils'
import './customPopupModal.scss'

interface CustomPopupModalProps {
  customPopup: CustomPopup
  handleCloseClick: () => void
}

const CustomPopupModal = ({
  customPopup,
  handleCloseClick,
}: CustomPopupModalProps) => {
  const { t } = useI18n()
  const isPopupOutdated = () =>
    DateTime.local() >= DateTime.fromISO(customPopup.endDate)
  const [icon, setIcon] = useState('')

  useEffect(() => {
    async function handleIcon() {
      const boIcon = await importIconById(customPopup.image, 'ecogesture')
      setIcon(boIcon ?? DefaultIcon)
    }
    handleIcon()
  }, [customPopup.image])

  return (
    <Dialog
      open={customPopup.popupEnabled && !isPopupOutdated()}
      disableEscapeKeyDown
      onClose={(event, reason): void => {
        event && reason !== 'backdropClick' && handleCloseClick()
      }}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper customPopupRoot',
      }}
    >
      <div id="accessibility-title">{customPopup.title}</div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="customPopupModal">
        <StyledIcon icon={icon} size={100} role="img" ariaHidden={false} />

        <div className="customPopup-title text-20-bold" data-testid="title">
          {customPopup.title}
        </div>

        <div
          className="customPopup-content text-16-normal"
          data-testid="description"
          dangerouslySetInnerHTML={{
            __html: customPopup.description,
          }}
        />

        <Button onClick={handleCloseClick} className="btnPrimary">
          {t('consumption.partner_issue_modal.ok')}
        </Button>
      </div>
    </Dialog>
  )
}

export default CustomPopupModal
