import IconButton from '@material-ui/core/IconButton'
import LeftArrowIcon from 'assets/icons/ico/left-arrow.svg'
import RightArrowIcon from 'assets/icons/ico/right-arrow.svg'
import classNames from 'classnames'
import DateNavigatorFormat from 'components/DateNavigator/DateNavigatorFormat'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { TimeStep } from 'enums'
import { DateTime } from 'luxon'
import React from 'react'
import './datenavigator.scss'

interface DateNavigatorProps {
  disableNext: boolean
  disablePrev: boolean
  handleNextDate: () => void
  handlePrevDate: () => void
  inlineDateDisplay?: boolean
  navigatorDate: DateTime
  timeStep: TimeStep
}

const DateNavigator = ({
  disableNext,
  disablePrev,
  handleNextDate,
  handlePrevDate,
  inlineDateDisplay = false,
  navigatorDate,
  timeStep,
}: DateNavigatorProps) => {
  const { t } = useI18n()

  return (
    <div className="date-navigator">
      <IconButton
        disabled={disablePrev}
        onClick={handlePrevDate}
        className={classNames('date-navigator-button', {
          ['disable']: disablePrev,
        })}
        aria-label={t('consumption.accessibility.button_previous_value')}
      >
        <Icon icon={LeftArrowIcon} size={16} />
      </IconButton>
      <DateNavigatorFormat
        timeStep={timeStep}
        date={navigatorDate}
        inline={inlineDateDisplay}
      />
      <IconButton
        disabled={disableNext}
        onClick={handleNextDate}
        className={classNames('date-navigator-button', {
          ['disable']: disableNext,
        })}
        aria-label={t('consumption.accessibility.button_next_value')}
      >
        <Icon icon={RightArrowIcon} size={16} />
      </IconButton>
    </div>
  )
}

export default DateNavigator
