import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import StyledEcogestureCard from 'components/CommonKit/Card/StyledEcogestureCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { Ecogesture } from 'models'
import React, { useEffect, useState } from 'react'
import { useNavigate } from 'react-router-dom'
import { importIconById } from 'utils/utils'
import EfficiencyRating from '../EfficiencyRating/EfficiencyRating'
import './ecogestureCard.scss'

const EcogestureCard = ({ ecogesture }: { ecogesture: Ecogesture }) => {
  const navigate = useNavigate()
  const [ecogestureIcon, setEcogestureIcon] = useState<string>('')

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(ecogesture.id, 'ecogesture')
      setEcogestureIcon(icon || defaultIcon)
    }
    if (ecogesture) {
      handleEcogestureIcon()
    }
  }, [ecogesture])

  return (
    <StyledEcogestureCard
      onClick={() => navigate(`/ecogesture/${ecogesture.id}`)}
      className="ecogesture-list-item"
    >
      <div className="ec-content">
        <StyledIcon className="Icon" icon={ecogestureIcon} size={50} />
        <div className="ec-content-short-name text-15-bold">
          {ecogesture.shortName}
        </div>
        <EfficiencyRating result={Math.round(ecogesture.efficiency)} />
      </div>
    </StyledEcogestureCard>
  )
}

export default EcogestureCard
