import { act, render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import * as storeHooks from 'store/hooks'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import EcogestureInitModal from './EcogestureInitModal'

const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('EcogestureInitModal component', () => {
  const store = createMockEcolyoStore()

  beforeEach(() => {
    jest.clearAllMocks()
  })
  it('should be rendered correctly', () => {
    const { baseElement } = render(
      <Provider store={store}>
        <EcogestureInitModal />
      </Provider>
    )
    expect(baseElement).toMatchSnapshot()
  })
  it('should close modal', async () => {
    render(
      <Provider store={store}>
        <EcogestureInitModal />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('ecogesture.initModal.btn1'))
    })
    expect(mockAppDispatch).toHaveBeenCalledTimes(1)
  })
  it('should close modal and launch form', async () => {
    render(
      <Provider store={store}>
        <EcogestureInitModal />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('ecogesture.initModal.btn2'))
    })
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-form?modal=false')
    expect(mockAppDispatch).toHaveBeenCalledTimes(1)
  })
})
