import { Button, IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import warningIcon from 'assets/icons/ico/warn-orange.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import './ecogestureResetModal.scss'

interface EcogestureResetModalProps {
  open: boolean
  closeEcogestureResetModal: () => void
  handleConfirmReset: () => void
}

const EcogestureResetModal = ({
  open,
  closeEcogestureResetModal,
  handleConfirmReset,
}: EcogestureResetModalProps) => {
  const { t } = useI18n()
  return (
    <Dialog
      open={open}
      onClose={closeEcogestureResetModal}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('feedback.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={closeEcogestureResetModal}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="eg-reset-modal">
        <Icon icon={warningIcon} size={63} />
        <div className="title text-20-bold">
          {t('ecogesture.resetModal.title_part1')}
          <span className="warn-title">
            {t('ecogesture.resetModal.title_part2')}
          </span>
          {t('ecogesture.resetModal.title_part3')}
          <span className="warn-title">
            {t('ecogesture.resetModal.title_part4')}
          </span>
          {t('ecogesture.resetModal.title_part5')}
          <span className="warn-title">
            {t('ecogesture.resetModal.title_part6')}
          </span>
        </div>
        <div className="text-16-normal text">
          {t('ecogesture.resetModal.text1')}
        </div>
        <div className="text-16-bold text">
          {t('ecogesture.resetModal.text2')}
        </div>
        <div className="buttons-container">
          <Button
            aria-label={t('ecogesture.resetModal.btn1')}
            onClick={closeEcogestureResetModal}
            className="btnSecondary"
          >
            {t('ecogesture.resetModal.btn1')}
          </Button>
          <Button
            aria-label={t('ecogesture.resetModal.btn2')}
            onClick={handleConfirmReset}
            className="btnPrimary"
          >
            {t('ecogesture.resetModal.btn2')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default EcogestureResetModal
