import Button from '@material-ui/core/Button'
import quizIcon from 'assets/icons/visu/quiz/questionMark.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import StarsContainer from 'components/CommonKit/StarsContainer/StarsContainer'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeUpdateFlag } from 'enums'
import { UserChallenge } from 'models'
import React from 'react'
import ChallengeService from 'services/challenge.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { useAppDispatch } from 'store/hooks'
import './quizBegin.scss'

const QuizBegin = ({ userChallenge }: { userChallenge: UserChallenge }) => {
  const { t } = useI18n()
  const client = useClient()
  const dispatch = useAppDispatch()
  const launchQuiz = async () => {
    const challengeService: ChallengeService = new ChallengeService(client)
    const userChallengeUpdated: UserChallenge =
      await challengeService.updateUserChallenge(
        userChallenge,
        UserChallengeUpdateFlag.QUIZ_START
      )
    dispatch(updateUserChallengeList(userChallengeUpdated))
  }

  return (
    <div className="quiz-container">
      <div className="quiz-begin-container">
        <StyledIcon className="quiz-icon" icon={quizIcon} size={180} />
        <StarsContainer
          result={userChallenge.progress.quizProgress}
          isQuizBegin={true}
        />

        <div className="quiz-explanation text-18-bold">
          {t('quiz.explanation')}
        </div>
        <div className="button-start">
          <Button
            aria-label={t('duel.accessibility.button_start_quiz')}
            onClick={launchQuiz}
            className="btnSecondary"
          >
            {t('duel.button_start')}
          </Button>
        </div>
      </div>
    </div>
  )
}

export default QuizBegin
