import { Dispatch, configureStore } from '@reduxjs/toolkit'
import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import {
  AnalysisState,
  ChallengeState,
  ChartState,
  GlobalState,
  ModalState,
  Profile,
  ProfileEcogesture,
  ProfileType,
} from 'models'
import { combineReducers } from 'redux'
import { analysisSlice } from './analysis/analysis.slice'
import { challengeSlice } from './challenge/challenge.slice'
import { chartSlice } from './chart/chart.slice'
import { globalSlice } from './global/global.slice'
import { modalSlice } from './modal/modal.slice'
import { profileSlice } from './profile/profile.slice'
import { profileEcogestureSlice } from './profileEcogesture/profileEcogesture.slice'
import { profileTypeSlice } from './profileType/profileType.slice'

export interface AppState {
  cozy: unknown
  ecolyo: {
    analysis: AnalysisState
    challenge: ChallengeState
    chart: ChartState
    global: GlobalState
    modal: ModalState
    profile: Profile
    profileEcogesture: ProfileEcogesture
    profileType: ProfileType
  }
}

/** Partial interfaces used for testing purposes */
export interface MockEcolyoState {
  analysis: Partial<AnalysisState>
  challenge: Partial<ChallengeState>
  chart: Partial<ChartState>
  global: Partial<GlobalState>
  modal: Partial<ModalState>
  profile: Partial<Profile>
  profileEcogesture: Partial<ProfileEcogesture>
  profileType: Partial<ProfileType>
}

const sentryReduxEnhancer = Sentry.createReduxEnhancer({})

const ecolyo = combineReducers({
  analysis: analysisSlice.reducer,
  challenge: challengeSlice.reducer,
  chart: chartSlice.reducer,
  global: globalSlice.reducer,
  modal: modalSlice.reducer,
  profile: profileSlice.reducer,
  profileEcogesture: profileEcogestureSlice.reducer,
  profileType: profileTypeSlice.reducer,
})

/** setupStore function to configure redux store taking an extra argument 'client' */
export const setupStore = (client: Client) => {
  const store = configureStore({
    reducer: {
      cozy: client.reducer(),
      ecolyo,
    },
    middleware: getDefaultMiddleware =>
      getDefaultMiddleware({
        serializableCheck: false,
        thunk: { extraArgument: { client } },
      }),
    devTools: true,
    enhancers: [sentryReduxEnhancer],
  })

  return store
}

// export type AppDispatch = ReturnType<typeof setupStore>['dispatch']
export type AppDispatch = Dispatch<any>
